<?php
/**
 * @version     4.0.0
 * @package     Com_AllVideoShare
 * @subpackage  Mod_AllVideoShareGallery
 * @author      Vinoth Kumar <admin@mrvinoth.com>
 * @copyright   Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined( '_JEXEC' ) or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;
use MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareHelper;
use MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareQuery;
use MrVinoth\Component\AllVideoShare\Site\Helper\AllVideoShareRoute;
use MrVinoth\Module\AllVideoShareGallery\Site\Helper\AllVideoShareGalleryHelper;

$items = AllVideoShareGalleryHelper::getVideos( $params );

// Vars
$columns = (int) $params->get( 'cols', 3 );
$column = 0;
$column_no = floor( 12 / $columns );

$column_class = 'col-sm-' . $column_no;

$image_ratio = $params->get( 'image_ratio', 56.25 );

$player = AllVideoShareQuery::getPlayer();
$player_ratio = $player->ratio;

$popup_class  = $params->get( 'popup' ) ? ' avs-popup' : '';

$custom_route = $params->get( 'link' );
if ( ! empty( $custom_route ) ) {
	$custom_route  = str_replace( 'slg=', '', $custom_route );
	$custom_route .= ! strpos( $custom_route, '?' ) ? '?slg=' : '&slg=';
}

$show_more = 0;
if ( $params->get( 'more' ) ) {
	$total = AllVideoShareGalleryHelper::getTotalVideos( $params );

	if ( $total > count( $items ) ) {
		$show_more = 1;
	}
}

// Import CSS & JS
$wa = $app->getDocument()->getWebAssetManager();

if ( ! $wa->assetExists( 'style', 'com_allvideoshare.site' ) ) {
	$wr = $wa->getRegistry();
	$wr->addRegistryFile( 'media/com_allvideoshare/joomla.asset.json' );
}

if ( $params->get( 'popup' ) ) {
	$wa->useStyle( 'com_allvideoshare.popup' )
		->useScript( 'com_allvideoshare.popup' )
		->useScript( 'com_allvideoshare.site' );
}

$wa->useStyle( 'com_allvideoshare.site' );

if ( $css = $params->get( 'custom_css' ) ) {
    $wa = $app->getDocument()->getWebAssetManager();
    $wa->addInlineStyle( $css );
}
?>

<div class="avs mod_allvideosharegallery videos">
	<?php if ( empty( $items ) ) : ?>
		<p class="text-muted">
			<?php echo Text::_( 'MOD_ALLVIDEOSHAREGALLERY_NO_ITEMS_FOUND' ); ?>
		</p>
	<?php else : ?>
		<div class="avs-grid<?php echo $popup_class; ?>" data-player_ratio="<?php echo (float) $player_ratio; ?>">
			<div class="row">
				<?php foreach ( $items as $i => $item ) : 
					if ( $column >= $columns ) {
						echo '</div><div class="row">';
						$column = 0;
					}

					if ( ! empty( $custom_route ) ) {
						$route = $custom_route . $item->slug;
					} else {
						$route = AllVideoShareRoute::getVideoRoute( $item->slug );
					}
					$item_link = Route::_( $route );

					if ( $params->get( 'popup' ) ) {
						$item_link = 'javascript:void(0)';
					}			

					$iframe_src = URI::root() . 'index.php?option=com_allvideoshare&view=player&vid=' . $item->id . "&format=raw&autoplay=1";
					?>
					<div class="avs-grid-item avs-video-<?php echo (int) $item->id; ?> <?php echo $column_class; ?>" data-mfp-src="<?php echo $iframe_src; ?>">
						<div class="card mb-3">
							<a href="<?php echo $item_link; ?>" class="avs-responsive-item" style="padding-bottom: <?php echo (float) $image_ratio; ?>%">
								<div class="avs-image" style="background-image: url( '<?php echo AllVideoShareHelper::getImage( $item ); ?>' );">&nbsp;</div>
								
								<svg class="avs-svg-icon avs-svg-icon-play" width="32" height="32" viewBox="0 0 32 32">
									<path d="M16 0c-8.837 0-16 7.163-16 16s7.163 16 16 16 16-7.163 16-16-7.163-16-16-16zM16 29c-7.18 0-13-5.82-13-13s5.82-13 13-13 13 5.82 13 13-5.82 13-13 13zM12 9l12 7-12 7z"></path>
								</svg>
							</a>

							<div class="card-body">
								<div class="aiovg-title">
									<a href="<?php echo $item_link; ?>" class="card-link"><?php echo $item->title; ?></a>
								</div>

								<?php if ( $params->get( 'views' ) ) : ?>
									<div class="avs-views-count">
										<?php
										Text::sprintf(
											'MOD_ALLVIDEOSHAREGALLERY_VIEWS_COUNT', 
											$item->views
										);
										?>
									</div>
								<?php endif; ?>
							</div>					
						</div>
					</div>
					<?php
					if ( $column >= $columns ) echo '</div>';
					$column++;
				endforeach; ?>
			</div>

			<?php if ( $show_more ) : ?>
				<a class="btn btn-primary" href="<?php echo ! empty( $params->get( 'category' ) ) ? AllVideoShareRoute::getRoute( $params->get( 'category' ), 'category' ) : AllVideoShareRoute::getRoute( 0, 'video' ); ?>">
					<?php echo Text::_( 'MOD_ALLVIDEOSHAREGALLERY_SHOW_MORE_BUTTON_LABEL' ); ?>
				</a>
			<?php endif; ?>
		</div>		
	<?php endif; ?>
</div>
