<?php
/**
 * @version     4.0.0
 * @package     Com_AllVideoShare
 * @subpackage  Mod_AllVideoSharePlayer
 * @author      Vinoth Kumar <admin@mrvinoth.com>
 * @copyright   Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace MrVinoth\Module\AllVideoSharePlayer\Site\Helper;

\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Language;
use \Joomla\CMS\Language\Text;

/**
 * Helper for mod_allvideoshareplayer
 *
 * @since  4.0.0
 */
Class AllVideoSharePlayerHelper {

	/**
	 * Retrieve video data
	 *
	 * @param   Joomla\Registry\Registry  &$params  Module parameters
	 *
	 * @return  object  The video item
	 * 
	 * @since   4.0.0
	 */
	public static function getItem( &$params ) {	
		$app = Factory::getApplication();
		$db  = Factory::getDbo();	

		// Vars
		$id = $params->get( 'videoid', 'latest' );
		$alias = $app->input->getCmd( 'slg', '' );
		$item = null;	

		if ( $params->get( 'autodetect' ) ) {
			$canAutoDetect = 1;
		
			if ( empty( $alias ) ) {
				$canAutoDetect = 0;
			}

			if ( $app->input->getCmd( 'option' ) == 'com_allvideoshare' && $app->input->getCmd( 'view' ) == 'category' ) { // Is a category view?
				$canAutoDetect = 0;
			}

			if ( $canAutoDetect ) {
				$id = 'alias';
			}
		}
		
		// Query
		$query = 'SELECT * FROM #__allvideoshare_videos WHERE state=1';
		
		switch ( $id ) {
			case 'latest':
				$query .= ' ORDER BY id DESC LIMIT 1';
				break;
			case 'popular':
				$query .= ' ORDER BY views DESC LIMIT 1';
				break;
			case 'alias':
				$query .= ' AND slg=' . $db->Quote( $alias );
				break;
			default:
				$query .= ' AND id=' . (int) $id;
		}

		$db->setQuery( $query );
		$item = $db->loadObject();		
		
		return $item;		
	}
	
}
