<?php
/**
 * @version    4.0.0
 * @package    Com_AllVideoShare
 * @author     Vinoth Kumar <admin@mrvinoth.com>
 * @copyright  Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace MrVinoth\Component\AllVideoShare\Site\Model;

// No direct access
\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Factory;
use \Joomla\CMS\Language\Text;
use \Joomla\CMS\MVC\Model\ItemModel;
use \Joomla\CMS\Object\CMSObject;
use \Joomla\CMS\Table\Table;
use \Joomla\Utilities\ArrayHelper;

/**
 * Class PlayerModel.
 *
 * @since  4.0.0
 */
class PlayerModel extends ItemModel {

	public $_item;	

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return  void
	 *
	 * @since   4.0.0
	 * @throws  Exception
	 */
	protected function populateState() {
		$app = Factory::getApplication();

		$params       = $app->getParams();
		$params_array = $params->toArray();

		$id = $app->input->getInt( 'vid' );
		$this->setState( 'video.id', $id );

		// Load the parameters
		$this->setState( 'params', $params );
	}

	/**
	 * Method to get an object.
	 *
	 * @param   integer  $id  The id of the object to get.
	 *
	 * @return  mixed    Object on success, false on failure.
	 *
	 * @since   4.0.0
	 * @throws  Exception
	 */
	public function getItem( $id = null ) {
		if ( $this->_item === null ) {
			$db = Factory::getDbo();

			$this->_item = false;

			if ( empty( $id ) ) {
				$id = $this->getState( 'video.id' );
			}

			// Get a level row instance
			$table = $this->getTable();

			// Attempt to load the row
			if ( $table && $table->load( $id ) ) {
				// Convert the Table to a clean CMSObject
				$properties  = $table->getProperties( 1 );
				$this->_item = ArrayHelper::toObject( $properties, CMSObject::class );				
			}

			if ( empty( $this->_item ) ) {
				throw new \Exception( Text::_( 'COM_ALLVIDEOSHARE_ITEM_NOT_LOADED' ), 404 );
			}
		}		

		return $this->_item;
	}

	/**
	 * Get an instance of Table class
	 *
	 * @param   string  $type    Name of the Table class to get an instance of.
	 * @param   string  $prefix  Prefix for the table class name. Optional.
	 * @param   array   $config  Array of configuration values for the Table object. Optional.
	 *
	 * @return  Table|bool  Table if success, false on failure.
	 * 
	 * @since   4.0.0
	 */
	public function getTable( $type = 'Video', $prefix = 'Administrator', $config = array() ) {
		return parent::getTable( $type, $prefix, $config );
	}
	
}
