<?php
/**
 * @version    4.0.0
 * @package    Com_AllVideoShare
 * @author     Vinoth Kumar <admin@mrvinoth.com>
 * @copyright  Copyright (c) 2012 - 2021 Vinoth Kumar. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace MrVinoth\Component\AllVideoShare\Site\Service;

// No direct access
\defined( '_JEXEC' ) or die;

use \Joomla\CMS\Component\Router\RouterView;
use \Joomla\CMS\Component\Router\Rules\RulesInterface;

/**
 * Class AllVideoShareNomenuRules.
 *
 * @since  4.0.0
 */
class AllVideoShareNomenuRules implements RulesInterface {

	/**
	 * Router this rule belongs to
	 *
	 * @var    RouterView
	 * @since  4.0.0
	 */
	protected $router;

	/**
	 * Class constructor.
	 *
	 * @param  RouterView  $router  Router this rule belongs to
	 *
	 * @since  4.0.0
	 */
	public function __construct( RouterView $router ) {
		$this->router = $router;
	}

	/**
	 * Dummy method to fullfill the interface requirements
	 *
	 * @param   array  &$query  The query array to process
	 *
	 * @return  void
	 *
	 * @since   4.0.0
	 */
	public function preprocess( &$query ) {
		// Do nothing
	}

	/**
	 * Parse an URL
	 *
	 * @param   array  &$segments  The URL segments to parse
	 * @param   array  &$vars      The vars that result from the segments
	 *
	 * @return  void
	 *
	 * @since   4.0.0
	 */
	public function parse( &$segments, &$vars ) {
		if ( $count = count( $segments ) ) {
			$componentViews = array( 'categories', 'category', 'videos', 'video', 'search', 'ads', 'player', 'user', 'uservideos', 'videoform' );
 
			if ( $count == 2 ) {
				$vars['view'] = $segments[0];
				$vars['slg']  = $segments[1];
			} else {
				if ( in_array( $segments[0], $componentViews ) ) {
					$vars['view'] = $segments[0];
				} else {
					$vars['slg'] = $segments[0];
				}				
			}

			$segments = array();
		}

		return;
	}

	/**
	 * Build an URL
	 *
	 * @param   array  &$query     The vars that should be converted
	 * @param   array  &$segments  The URL segments to create
	 *
	 * @return  void
	 *
	 * @since   4.0.0
	 */
	public function build( &$query, &$segments ) {
		if ( isset( $query['view'] ) ) {
			$segments[] = $query['view'];
			unset( $query['view'] );
		}
		
		if ( isset( $query['slg'] ) ) {
			if ( ! empty( $query['slg'] ) ) {
				$segments[] = $query['slg'];
			}
			
			unset( $query['slg'] );
		}
	}

}
